@@ -25,7 +25,7 @@
 #'
 #' @return A data frame of all query variant RS numbers, respective QTL which are in LD with query variant,
 #' and associated gene expression.
-#' @importFrom httr POST content stop_for_status
+#' @importFrom httr POST content stop_for_status http_error
 #' @importFrom utils capture.output read.delim write.table
 #' @export
 #'
@@ -232,6 +232,17 @@ jsonbody <- list(snps = snps_to_upload,
                  window = win_size
                 )
 
+# before full 'POST command', check if LDlink server is up and accessible...
+# if server is down pkg should fail gracefully with informative message (not error)
+r_url <- POST(url)
+if (httr::http_error(r_url)) { # if server is down use message (and not an error)
+  message("The LDlink server is down or not accessible. Please try again later.")
+  return(NULL)
+  # if server is working then proceed
+} else {
+  message("\nLDlink server is working...\n")
+}
+
 # URL string
 url_str <- paste(url, "?", "token=", token, sep="")
 
